@@ -1,3 +1,4 @@
+/*	$Id: g_interface.c,v 1.12 2001/04/18 02:52:03 riq Exp $	*/
 /******************************************************************************
  *                        FUNCIONES GNOMES  y/o GTK                           *
  *****************************************************************************/
@@ -7,7 +8,7 @@
 #include <config.h>
 #include <gnome.h>
 
-#include "../gbnserver/protocol.h"
+#include "protocol.h"
 #include "gbnclient.h"
 #include "cliente.h"
 #include "proceso.h"
@@ -16,6 +17,8 @@
 #include "configure.h"
 #include "sendmsg.h"
 #include "version.h"
+#include "g_connect.h"
+#include "support.h"
 
 /* pixmaps */
 #include "about.xpm"
@@ -45,33 +48,46 @@
 #include "barco4v_h.xpm"
 #include "robot.xpm"
 #include "random.xpm"
+#include "ships.xpm"
 
-static void message_dlg_clicked(GtkWidget *widget, int button,gpointer data)
+
+/* callback de los botones */
+void on_connect_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	if (button == 0) /* Yes */
-		gtk_main_quit();
-	else /* No */
-		gnome_dialog_close(GNOME_DIALOG(widget));
+	conectar_view();
 }
-
-gboolean g_do_exit(GtkWidget *widget, gpointer data)
+void on_disconnect_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	static GtkWidget *box = NULL;
+	send_disconnect();
+}
+void on_launchrobot_activate (GtkMenuItem *menuitem, gpointer user_data)
+{
+	char buf[2000];
 
-	if (box == NULL) {
-		box = gnome_message_box_new (_("Really quit?"),
-			GNOME_MESSAGE_BOX_QUESTION,
-			GNOME_STOCK_BUTTON_YES,
-			GNOME_STOCK_BUTTON_NO,
-			NULL);
-		gtk_signal_connect (GTK_OBJECT (box), "clicked",
-			GTK_SIGNAL_FUNC (message_dlg_clicked), NULL);
-
-		gtk_window_set_modal (GTK_WINDOW(box),TRUE);
-		gnome_dialog_close_hides(GNOME_DIALOG(box), TRUE);
-	}
-	gtk_widget_show (box);
-	return TRUE;
+	snprintf(buf,sizeof(buf)-1,BINDIR"/gbnrobot --port %d --server %s",usuario.port,usuario.server);
+	buf[sizeof(buf)-1]=0;
+	gnome_execute_shell(NULL,buf);
+}
+void on_random_activate (GtkMenuItem *menuitem, gpointer user_data)
+{
+	generar();
+}
+void on_start_activate (GtkMenuItem *menuitem, gpointer user_data)
+{
+	send_start();
+}
+void on_sendships_activate (GtkMenuItem *menuitem, gpointer user_data)
+{
+	send_board();
+}
+void on_status_activate (GtkMenuItem *menuitem, gpointer user_data)
+{
+	send_status();
+}
+void on_exit_activate(GtkWidget *widget, gpointer data)
+{
+	send_disconnect();
+	gtk_main_quit();
 }
 
 
@@ -89,6 +105,9 @@ gboolean g_box_lost()
 			GNOME_MESSAGE_BOX_INFO,
 			GNOME_STOCK_BUTTON_OK,
 			NULL);
+		if( box==NULL) return FALSE;
+
+		generic_window_set_parent( box, GTK_WINDOW(window) );
 		
 		gtk_signal_connect (GTK_OBJECT (box), "clicked",
 			GTK_SIGNAL_FUNC (g_cerrar), NULL);
@@ -109,7 +128,11 @@ gboolean g_box_win()
 			GNOME_MESSAGE_BOX_INFO,
 			GNOME_STOCK_BUTTON_OK,
 			NULL);
-		
+
+		if( box==NULL) return FALSE;
+
+		generic_window_set_parent( box, GTK_WINDOW(window) );
+
 		gtk_signal_connect (GTK_OBJECT (box), "clicked",
 			GTK_SIGNAL_FUNC (g_cerrar), NULL);
 
@@ -122,36 +145,91 @@ gboolean g_box_win()
 
 void about( GtkWidget *widget, gpointer data )
 {
-	GtkWidget *about;
-	gchar *authors[] = {
-		"riq (rquesada@pjn.gov.ar)",
+	GtkWidget *href, *hbox;
+	static GtkWidget *about = NULL;
+	static const char *authors[] = {
+		"Ricardo C. Quesada (riq@core-sdi.com)",
 		NULL
 	};
-   
-	about = gnome_about_new (_("Batalla Naval client"), VERSION,
-			"(C) 1998,99 Ricardo C. Quesada",
-			(const char**) authors,
-			_("A multiplayer, multirobot, networked battleship game."),
-			"gnome-gbatnav.png");
-	gtk_widget_show (about);
+
+	if (!about) {
+
+		about = gnome_about_new (_("Batalla Naval client"),
+				VERSION,
+				_("(C) 1998-2001 Ricardo C. Quesada"),
+				(const char**) authors,
+				_("A multiplayer networked battleship game."),
+				"gnome-gbatnav.png");
+
+		gtk_signal_connect (GTK_OBJECT (about), "destroy",
+				    GTK_SIGNAL_FUNC (gtk_widget_destroyed),
+				    &about);
+
+
+		hbox = gtk_hbox_new (TRUE, 0);
+		href = gnome_href_new ("http://batnav.sourceforge.net", _("Batalla Naval Home Page"));
+		gtk_box_pack_start (GTK_BOX (hbox), href, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (about)->vbox),
+			    hbox, TRUE, FALSE, 0);
+		gtk_widget_show_all (hbox);
+	}
+
+	gtk_widget_show_now (about);
+	raise_and_focus (about);
 }
 
+
+enum {
+	WID_G_CONNEC,
+	WID_G_DISCON,
+	WID_G_XXX0,
+	WID_G_ROBOT,
+};
+
 GnomeUIInfo gamemenu[] = 
 {
-	{ GNOME_APP_UI_ITEM, N_("_Generate random board"), NULL, generar, NULL, NULL,
-		GNOME_APP_PIXMAP_DATA, random_xpm, 0, 0, NULL },
-
-	{ GNOME_APP_UI_ITEM, N_("_Launch a robot in server"), NULL, init_robot, NULL, NULL, 
-		GNOME_APP_PIXMAP_DATA, robot_xpm, 0, 0, NULL }, 
-
-	GNOMEUIINFO_MENU_SCORES_ITEM( NULL, NULL),
+	{ GNOME_APP_UI_ITEM, N_("_Connect"), NULL, on_connect_activate, NULL, NULL,
+		GNOME_APP_PIXMAP_DATA, NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, N_("_Disconnect"), NULL, on_disconnect_activate, NULL, NULL,
+		GNOME_APP_PIXMAP_DATA, NULL, 0, 0, NULL },
 	GNOMEUIINFO_SEPARATOR, 
-	GNOMEUIINFO_MENU_EXIT_ITEM(g_do_exit,NULL),
+	{ GNOME_APP_UI_ITEM, N_("_Launch a robot"), NULL, on_launchrobot_activate, NULL, NULL, 
+		GNOME_APP_PIXMAP_DATA, robot_xpm, 0, 0, NULL }, 
+	GNOMEUIINFO_SEPARATOR, 
+	GNOMEUIINFO_MENU_EXIT_ITEM(on_exit_activate,NULL),
 	GNOMEUIINFO_END
 };
 
-GnomeUIInfo settingsmenu[] = {
-	GNOMEUIINFO_MENU_PREFERENCES_ITEM( configure, NULL),
+enum {
+	WID_A_RANDOM,
+	WID_A_SEND,
+	WID_A_START,
+	WID_A_STATUS,
+};
+
+GnomeUIInfo actionsmenu[] =
+{
+	{ GNOME_APP_UI_ITEM, N_("_Generate random board"), NULL, on_random_activate, NULL, NULL,
+		GNOME_APP_PIXMAP_DATA, NULL, 0, 0, NULL },
+
+	{ GNOME_APP_UI_ITEM, N_("_Send ships"), NULL, on_sendships_activate, NULL, NULL,
+		GNOME_APP_PIXMAP_DATA, NULL, 0, 0, NULL },
+
+	{ GNOME_APP_UI_ITEM, N_("_Start"), NULL, on_start_activate, NULL, NULL,
+		GNOME_APP_PIXMAP_DATA, NULL, 0, 0, NULL },
+
+	{ GNOME_APP_UI_ITEM, N_("Status"), NULL, on_status_activate, NULL, NULL,
+		GNOME_APP_PIXMAP_DATA, NULL, 0, 0, NULL },
+
+	GNOMEUIINFO_END
+};
+
+GnomeUIInfo viewmenu[] = {
+	{ GNOME_APP_UI_TOGGLEITEM, N_("View lot of messages"), N_("View lot of messages"),
+	configure, NULL, NULL,
+	GNOME_APP_PIXMAP_NONE, NULL,
+	0, 0, NULL },
+
 	GNOMEUIINFO_END
 };
 
@@ -165,33 +243,54 @@ GnomeUIInfo helpmenu[] =
 GnomeUIInfo mainmenu[] = 
 {
         GNOMEUIINFO_MENU_GAME_TREE(gamemenu),
-	GNOMEUIINFO_MENU_SETTINGS_TREE(settingsmenu),
+	{ GNOME_APP_UI_SUBTREE_STOCK, N_("_Actions"), NULL, actionsmenu, NULL, NULL, \
+		(GnomeUIPixmapType) 0, NULL, 0,	(GdkModifierType) 0, NULL },
+	GNOMEUIINFO_MENU_VIEW_TREE(viewmenu),
         GNOMEUIINFO_MENU_HELP_TREE(helpmenu),
 	GNOMEUIINFO_END
 };
 
+enum {
+	WID_CONNEC,
+	WID_XXX0,
+	WID_RANDOM,
+	WID_SEND,
+	WID_XXX1,
+	WID_ROBOT,
+	WID_XXX2,
+	WID_START,
+};
+
+
 GnomeUIInfo main_toolbarinfo[] =
 {
-	{GNOME_APP_UI_ITEM, N_("Preferences..."), N_("Preferences..."),
-	configure, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP, 0, 0, NULL},
+	{GNOME_APP_UI_ITEM, N_("Connect"), N_("Connect to server"),
+	on_connect_activate, NULL, NULL,
+	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_NEW, 0, 0, NULL},
+
+	GNOMEUIINFO_SEPARATOR,
 	
 	{GNOME_APP_UI_ITEM, N_("Random"), N_("Generate a random board"),
-	generar, NULL, NULL,
+	on_random_activate, NULL, NULL,
 	GNOME_APP_PIXMAP_DATA, random_xpm, 0, 0, NULL},
 
+	{GNOME_APP_UI_ITEM, N_("Send ships"), N_("Send ships to server"),
+	on_sendships_activate, NULL, NULL,
+	GNOME_APP_PIXMAP_DATA, ships_xpm, 0, 0, NULL},
+
+
 	GNOMEUIINFO_SEPARATOR,
 
-	{GNOME_APP_UI_ITEM, N_("Robot"), N_("Launch a robot in server"),
-	init_robot, NULL, NULL,
+	{GNOME_APP_UI_ITEM, N_("Robot"), N_("Launch a robot"),
+	on_launchrobot_activate, NULL, NULL,
 	GNOME_APP_PIXMAP_DATA, robot_xpm, 0, 0, NULL},
   
 	GNOMEUIINFO_SEPARATOR,
-	
-	{GNOME_APP_UI_ITEM, N_("Exit"), N_("Quit Batalla Naval"),
-	g_do_exit, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 0, 0, NULL},
 
+	{GNOME_APP_UI_ITEM, N_("Start"), N_("Start the game"),
+	on_start_activate, NULL, NULL,
+	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_TIMER, 0, 0, NULL},
+	
 	{GNOME_APP_UI_ENDOFINFO}
 };
 
@@ -201,6 +300,8 @@ GnomeUIInfo main_toolbarinfo[] =
 void init_X( )
 {
 	GtkTooltips *tooltips;
+	GtkWidget *inputline;
+	GtkWidget *vbox_buttons;
 
 #ifdef ENABLE_NLS
 # define ELEMENTS(x) (sizeof(x) / sizeof(x[0])) 
@@ -221,14 +322,14 @@ void init_X( )
 	gnome_app_create_menus(GNOME_APP(window), mainmenu);
 	gnome_app_create_toolbar(GNOME_APP(window), main_toolbarinfo);
 
-	gtk_menu_item_right_justify(GTK_MENU_ITEM(mainmenu[1].widget));
+/*	gtk_menu_item_right_justify(GTK_MENU_ITEM(mainmenu[3].widget)); */
 	gtk_widget_realize (window);
    
 	gtk_signal_connect ( GTK_OBJECT( window), "destroy",
-		GTK_SIGNAL_FUNC( g_do_exit ),
+		GTK_SIGNAL_FUNC( on_exit_activate ),
 		GTK_OBJECT(window) );
 	gtk_signal_connect ( GTK_OBJECT( window), "delete_event",
-		GTK_SIGNAL_FUNC( g_do_exit ),
+		GTK_SIGNAL_FUNC( on_exit_activate ),
 		GTK_OBJECT(window) );
   
 	tooltips=gtk_tooltips_new();
@@ -251,7 +352,7 @@ void init_X( )
 	/******************** LEFT *******************/
 	notebook_left = gtk_notebook_new();
 	gtk_notebook_set_tab_pos( GTK_NOTEBOOK(notebook_left),GTK_POS_TOP );
-	gtk_box_pack_start( GTK_BOX(hbox),notebook_left,TRUE,TRUE,0);
+	gtk_box_pack_start( GTK_BOX(hbox),notebook_left,FALSE,TRUE,0);
 	gtk_widget_show (notebook_left);
    
 	/* respecto al drawing_left */
@@ -274,7 +375,7 @@ void init_X( )
 	gtk_widget_show( hbox_text_help );
    
 	text_help = gtk_text_new(NULL,NULL);
-	gtk_box_pack_start( GTK_BOX(hbox_text_help), text_help, TRUE,TRUE,0);
+	gtk_box_pack_start( GTK_BOX(hbox_text_help), text_help, FALSE,TRUE,0);
 	gtk_widget_show(text_help);
    
 	vscrollbar_help = gtk_vscrollbar_new (GTK_TEXT (text_help)->vadj);
@@ -289,73 +390,19 @@ void init_X( )
 	bn_help();
       
 	/* center */
-   
-	vbox_buttons = gtk_vbox_new ( FALSE, 10);
+
+	vbox_buttons = gtk_vbox_new ( TRUE, 10);
 	gtk_container_add ( GTK_CONTAINER (hbox), vbox_buttons );
-	gtk_container_border_width( GTK_CONTAINER(vbox_buttons),10);
+	gtk_container_border_width( GTK_CONTAINER(vbox_buttons),20);
 	gtk_widget_show( vbox_buttons );
-   
-	button_connect = gtk_button_new();
-	button_connect_label = gtk_label_new(_("Connect"));
-	gtk_misc_set_alignment( GTK_MISC(button_connect_label),0.5,0.5);
-	gtk_container_add( GTK_CONTAINER( button_connect), button_connect_label);
-	gtk_widget_show( button_connect_label);
 
-	gtk_box_pack_start( GTK_BOX(vbox_buttons), button_connect, TRUE,TRUE,0);
-	gtk_signal_connect_object( GTK_OBJECT (button_connect), "clicked",
-		GTK_SIGNAL_FUNC(init_cliente),
-		GTK_OBJECT (window) );
-	gtk_widget_show(button_connect);
-	gtk_tooltips_set_tip (tooltips,button_connect,
-		_("Connect to/disconnect from the server"), 
-		_("Connect to/disconnect from the server"));
-   
-   
-	button_sendboard = gtk_button_new();
-	button_sendboard_label = gtk_label_new(_("Send ships"));
-	gtk_misc_set_alignment( GTK_MISC(button_sendboard_label),0.5,0.5);
-	gtk_container_add( GTK_CONTAINER( button_sendboard), button_sendboard_label);
-	gtk_widget_show( button_sendboard_label);
-	gtk_box_pack_start( GTK_BOX(vbox_buttons), button_sendboard,TRUE,TRUE,0);
-	gtk_signal_connect_object( GTK_OBJECT (button_sendboard), "clicked",
-		GTK_SIGNAL_FUNC(play),
-		GTK_OBJECT (window) );
-	gtk_widget_set_sensitive(button_sendboard,FALSE);
-	gtk_widget_show(button_sendboard);
-	gtk_tooltips_set_tip (tooltips,button_sendboard,
-		_("Send ships to the server/ Start the game"),
-		_("Send ships to the server/ Start the game"));
-
-   
-	button_sendmsg = gtk_button_new_with_label ("Send Message");
-	gtk_box_pack_start( GTK_BOX(vbox_buttons), button_sendmsg,TRUE,TRUE,0);
-	gtk_signal_connect_object( GTK_OBJECT (button_sendmsg), "clicked",
-		GTK_SIGNAL_FUNC(bnsendmsg),
-		GTK_OBJECT (window) );
-	gtk_widget_set_sensitive(button_sendmsg,FALSE);
-	gtk_widget_show(button_sendmsg);
-	gtk_tooltips_set_tip (tooltips,button_sendmsg,
-		_("Send a message"),
-		_("Send a message"));
-   
-	button_status = gtk_button_new_with_label ("Status");
-	gtk_box_pack_start( GTK_BOX(vbox_buttons), button_status,TRUE,TRUE,0);
-	gtk_signal_connect_object( GTK_OBJECT (button_status), "clicked",
-		GTK_SIGNAL_FUNC(status),
-		GTK_OBJECT (window) );
-	gtk_widget_set_sensitive(button_status,FALSE);
-	gtk_widget_show(button_status);		
-	gtk_tooltips_set_tip (tooltips,button_status,
-		_("Status of the game"),
-		_("Status of the game"));
-   
 
 	/* right */
 	notebook_right = gtk_notebook_new();
 	gtk_signal_connect ( GTK_OBJECT ( notebook_right ), "switch_page",
 		GTK_SIGNAL_FUNC ( page_switch ), NULL );
 	gtk_notebook_set_tab_pos( GTK_NOTEBOOK(notebook_right),GTK_POS_TOP );
-	gtk_box_pack_start( GTK_BOX(hbox),notebook_right,TRUE,TRUE,0);
+	gtk_box_pack_start( GTK_BOX(hbox),notebook_right,FALSE,TRUE,0);
  	gtk_container_border_width( GTK_CONTAINER( notebook_right), 0 );
 	gtk_notebook_set_scrollable( GTK_NOTEBOOK(notebook_right) , TRUE );
 	gtk_notebook_set_show_tabs( GTK_NOTEBOOK(notebook_right) , TRUE );
@@ -395,10 +442,17 @@ void init_X( )
    
 	gtk_text_freeze(GTK_TEXT(text));
 	gtk_widget_realize(text); 
-	gtk_text_insert( GTK_TEXT(text),NULL,NULL,NULL,"Gnome Batalla Naval client v"IPVERSION" by riq (c) 1998,99" ,-1);
+	gtk_text_insert( GTK_TEXT(text),NULL,NULL,NULL,"Gnome Batalla Naval client v"IPVERSION" by riq (c) 1998-2001" ,-1);
 	gtk_text_thaw(GTK_TEXT(text));
 
-   
+  
+	inputline = gtk_entry_new();
+	gtk_box_pack_start( GTK_BOX( vbox ), inputline, FALSE, FALSE, 0 );
+	gtk_widget_show(inputline);
+	gtk_signal_connect(GTK_OBJECT(inputline), "activate",
+		GTK_SIGNAL_FUNC(inputline_return), NULL);
+
+
 	/* StatusBar */
 	hbox_status = gtk_hbox_new ( FALSE, 0);
 	gtk_container_add ( GTK_CONTAINER(vbox), hbox_status );
@@ -457,3 +511,73 @@ void init_X( )
 	/* Principal */   
 	gtk_widget_show( window);
 }
+
+/**
+ * @fn void update_sensi()
+ */
+void update_sensi()
+{
+
+	/* connect & disconnect */
+	if( usuario.play == DISCON ) {
+		gtk_widget_set_sensitive (main_toolbarinfo[WID_CONNEC].widget, TRUE);
+		gtk_widget_set_sensitive (gamemenu[WID_G_CONNEC].widget, TRUE);
+		gtk_widget_set_sensitive (gamemenu[WID_G_DISCON].widget, FALSE);
+	} else {
+		gtk_widget_set_sensitive (main_toolbarinfo[WID_CONNEC].widget, FALSE);
+		gtk_widget_set_sensitive (gamemenu[WID_G_CONNEC].widget, FALSE);
+		gtk_widget_set_sensitive (gamemenu[WID_G_DISCON].widget, TRUE);
+	}
+
+	/* random y send*/
+	if( usuario.play == CONNEC ) {
+		gtk_widget_set_sensitive (main_toolbarinfo[WID_RANDOM].widget, TRUE);
+		gtk_widget_set_sensitive (main_toolbarinfo[WID_SEND].widget, TRUE);
+		gtk_widget_set_sensitive (actionsmenu[WID_A_RANDOM].widget, TRUE);
+		gtk_widget_set_sensitive (actionsmenu[WID_A_SEND].widget, TRUE);
+
+	} else {
+		gtk_widget_set_sensitive (main_toolbarinfo[WID_RANDOM].widget, FALSE);
+		gtk_widget_set_sensitive (main_toolbarinfo[WID_SEND].widget, FALSE);
+		gtk_widget_set_sensitive (actionsmenu[WID_A_RANDOM].widget, FALSE);
+		gtk_widget_set_sensitive (actionsmenu[WID_A_SEND].widget, FALSE);
+	}
+
+	/* robot */
+	if( usuario.play == CONNEC || usuario.play == BOARD ) {
+		gtk_widget_set_sensitive (main_toolbarinfo[WID_ROBOT].widget, TRUE);
+		gtk_widget_set_sensitive (gamemenu[WID_G_ROBOT].widget, TRUE);
+	} else {
+		gtk_widget_set_sensitive (main_toolbarinfo[WID_ROBOT].widget, FALSE);
+		gtk_widget_set_sensitive (gamemenu[WID_G_ROBOT].widget, FALSE);
+	}
+	
+	/* start */
+	if( usuario.play == BOARD ) {
+		gtk_widget_set_sensitive (main_toolbarinfo[WID_START].widget, TRUE);
+		gtk_widget_set_sensitive (actionsmenu[WID_A_START].widget, TRUE);
+	} else {
+		gtk_widget_set_sensitive (main_toolbarinfo[WID_START].widget, FALSE);
+		gtk_widget_set_sensitive (actionsmenu[WID_A_START].widget, FALSE);
+	}
+
+	/* status */
+	if( usuario.play == DISCON ) {
+		gtk_widget_set_sensitive (actionsmenu[WID_A_STATUS].widget, FALSE);
+	} else {
+		gtk_widget_set_sensitive (actionsmenu[WID_A_STATUS].widget, TRUE);
+	}
+
+	/* ggz */
+	if( usuario.with_ggz ) {
+		/* connect */
+		gtk_widget_set_sensitive (main_toolbarinfo[WID_CONNEC].widget, FALSE);
+		gtk_widget_set_sensitive (gamemenu[WID_G_CONNEC].widget, FALSE);
+
+		/* robot */
+		gtk_widget_set_sensitive (main_toolbarinfo[WID_ROBOT].widget, FALSE);
+		gtk_widget_set_sensitive (gamemenu[WID_G_ROBOT].widget, FALSE);
+	} 
+
+	return;
+}
