@@ -1,4 +1,4 @@
-/*	$Id: gbnclient.c,v 1.11 2001/04/18 02:52:03 riq Exp $	*/
+/*	$Id: gbnclient.c,v 1.14 2002/04/07 17:57:05 riq Exp $	*/
 /*
  * Gnome Batalla Naval
  * Gnome client
@@ -47,7 +47,9 @@ static struct poptOption options[] =
 	{ "port", 'p', POPT_ARG_INT, &usuario.port, 0, N_("Port number. Default is 1995"),NULL},
 	{ "server", 's', POPT_ARG_STRING, &server_tmp, 0, N_("Server name. Default is localhost"),"SERVER" },
 	{ "player", 'n', POPT_ARG_STRING, &nombre_tmp, 0, N_("Player name. Default is your login name"),"PLAYERNAME"},
+#ifdef WITH_GGZ
 	{ "ggz", 0, POPT_ARG_NONE, &usuario.with_ggz, 0, N_("Enable GGZ mode"),NULL },
+#endif /* WITH_GGZ */
 	{ NULL, '\0',  0, NULL }
 };
 
@@ -454,7 +456,11 @@ int send_connect()
 {
 
 	if( usuario.with_ggz ) {
-		usuario.sock = ggz_client_connect();
+#ifdef WITH_GGZ
+		usuario.sock = ggzmod_connect();
+#else
+		usuario.sock = -1;
+#endif /* ! WITH_GGZ */
 	} else {
 		usuario.sock = net_connect_tcp( usuario.server, usuario.port );
 	}
@@ -469,7 +475,7 @@ int send_connect()
     
 	usuario.play=CONNEC;
 
-	if( !usuario.with_ggz )
+	if( ! usuario.with_ggz )
 		bnwrite(usuario.sock,BN_NUMJUG);
     
 	update_sensi();
@@ -490,10 +496,18 @@ int send_disconnect()
 		usuario.names[i][0]=0;
 		usuario.pages[i]=i;
 	}
-	bnwrite(usuario.sock,BN_EXIT);
 	usuario.play=DISCON;
 	gdk_input_remove( usuario.tag );
-	close( usuario.sock );
+
+#if WITH_GGZ
+	if( usuario.with_ggz )
+		ggzmod_disconnect();
+	else
+#endif /* WITH_GGZ */
+	{
+		bnwrite(usuario.sock,BN_EXIT);
+		close( usuario.sock );
+	}
 	
 	/* gtk v1.2 no me actualiza este evento. forzarlo */
 	expose_event( drawing_left, NULL );
@@ -602,9 +616,6 @@ int main (int argc, char *argv[])
 	gtk_signal_connect (GTK_OBJECT (client), "save_yourself",
    		GTK_SIGNAL_FUNC (save_state), argv[0]);
 
-	if(usuario.with_ggz)
-		ggz_client_init("batnav");
-	
 	init_datos();
 	init_X();
 
@@ -623,8 +634,5 @@ int main (int argc, char *argv[])
    
 	gtk_main ();
 
-	if(usuario.with_ggz)
-		ggz_client_quit();
-
 	return 0;
 }
