@@ -1,3 +1,4 @@
+/*	$Id: gbnclient.h,v 1.3 2001/04/06 15:15:22 riq Exp $	*/
 
 /* 
 	Includes de gbnclient
@@ -42,15 +43,17 @@ void fillboard( char *filltable, int a );
 
 char* inteliclient( char *table);
 
-int play( void );
-
-void status( );
+int send_start( void );
+int send_board( void );
+int send_status( void );
+int send_robot( void );
+int send_connect( void );
+int send_disconnect( void );
 
 void init_datos( void );
 
-void init_cliente( void );
+int init_cliente( void );
 
-int init_robot( void );
 
 void bn_help( void );
    
