@@ -1,4 +1,4 @@
-/*	$Id: robot_proceso.c,v 1.16 2001/04/18 02:52:04 riq Exp $	*/
+/*	$Id: robot_proceso.c,v 1.17 2002/04/07 17:22:16 riq Exp $	*/
 /****************************************************************************
  	Funcion basada en la del cliente.
 	Comportamiento del Robot a nivel BNP
@@ -39,6 +39,10 @@ static const struct poptOption options[] =
 		N_("Server name. Default is localhost"),"SERVER"},
 	{ "port", 'p', POPT_ARG_INT, &cliente.port, 0,
 		N_("Port number. Default is 1995"),"PORT"},
+#ifdef WITH_GGZ
+	{ "ggz", 0, POPT_ARG_NONE, &cliente.with_ggz, 0,
+		N_("Enable GGZ mode"),NULL },
+#endif /* WITH_GGZ */
 	{ "nogui", 0, POPT_ARG_NONE, &cliente.with_nogui, 0,
 		N_("Disable the GUI"),NULL },
 	{ NULL, '\0',  0, NULL }
@@ -402,7 +406,9 @@ static void robot_lost( char *str)
 }
 static void robot_ggz()
 {
+	bnwrite(cliente.sock,BN_NUMJUG);
 }
+
 static void robot_win( int j, char *str)
 {
 	int a;
@@ -507,7 +513,13 @@ static int robot_proceso( gpointer data, int sock, GdkInputCondition GDK_INPUT_R
 
 static int robot_init( void )
 {
-	cliente.sock = net_connect_tcp( cliente.server, cliente.port);
+#ifdef WITH_GGZ
+	if( cliente.with_ggz ) {
+		cliente.with_nogui = 1;
+		cliente.sock = 3;
+	} else
+#endif /* WITH_GGZ */
+		cliente.sock = net_connect_tcp( cliente.server, cliente.port);
 
 	if(cliente.sock<0) {
 		printf(_("gbnrobot Error: Is the server running?\n"));
