@@ -1,4 +1,4 @@
-/*	$Id: play.c,v 1.14 2001/04/24 00:11:37 riq Exp $	*/
+/*	$Id: play.c,v 1.17 2002/04/07 17:58:08 riq Exp $	*/
 /***********************************************************************
 	play.c
 	Funcion que se encarga de poner las reglas al juego y todo eso
@@ -393,8 +393,10 @@ static void token_name( int fd, char *str )
 		return;
 
 	strncpy(usuario.names[j],str,MAXNAMELEN-1);
+#ifdef WITH_GGZ
 	if(usuario.with_ggz)
 		batnavggz_find_ggzname(fd,usuario.names[j],sizeof(usuario.names[j])-1);
+#endif /* WITH_GGZ */
 
 	say_in_clist(j,C_NAME,usuario.names[j]);
 }
